@@ -9,6 +9,8 @@ NULL
 #' auto-commit on.
 #' [DBI::dbWithTransaction()] is a convenient wrapper that makes sure that
 #' `dbCommit()` or `dbRollback()` is called.
+#' A helper function `sqliteIsTransacting()` is available to check the current
+#' transaction status of the connection.
 #'
 #' @seealso
 #' The corresponding generic functions [DBI::dbBegin()], [DBI::dbCommit()],
@@ -45,6 +47,7 @@ NULL
 #' # Named savepoints can be nested --------------------------------------------
 #' dbBegin(con, name = "a")
 #' dbBegin(con, name = "b")
+#' sqliteIsTransacting(con)
 #' dbRollback(con, name = "b")
 #' dbCommit(con, name = "a")
 #'
@@ -52,53 +55,6 @@ NULL
 #' @name sqlite-transaction
 NULL
 
-#' @export
-#' @rdname sqlite-transaction
-setMethod("dbBegin", "SQLiteConnection", function(conn, .name = NULL, ..., name = NULL) {
-  name <- compat_name(name, .name)
-  if (is.null(name)) {
-    dbExecute(conn, "BEGIN")
-  } else {
-    dbExecute(conn, paste0("SAVEPOINT ", dbQuoteIdentifier(conn, name)))
-  }
-
-  invisible(TRUE)
-})
-
-#' @export
-#' @rdname sqlite-transaction
-setMethod("dbCommit", "SQLiteConnection", function(conn, .name = NULL, ..., name = NULL) {
-  name <- compat_name(name, .name)
-  if (is.null(name)) {
-    dbExecute(conn, "COMMIT")
-  } else {
-    dbExecute(conn, paste0("RELEASE SAVEPOINT ", dbQuoteIdentifier(conn, name)))
-  }
-
-  invisible(TRUE)
-})
-
-#' @export
-#' @rdname sqlite-transaction
-setMethod("dbRollback", "SQLiteConnection", function(conn, .name = NULL, ..., name = NULL) {
-  name <- compat_name(name, .name)
-  if (is.null(name)) {
-    dbExecute(conn, "ROLLBACK")
-  } else {
-    # The ROLLBACK TO command reverts the state of the database back to what it
-    # was just after the corresponding SAVEPOINT. Note that unlike that plain
-    # ROLLBACK command (without the TO keyword) the ROLLBACK TO command does not
-    # cancel the transaction. Instead of cancelling the transaction, the
-    # ROLLBACK TO command restarts the transaction again at the beginning. All
-    # intervening SAVEPOINTs are canceled, however.
-    name_quoted <- dbQuoteIdentifier(conn, name)
-    dbExecute(conn, paste0("ROLLBACK TO ", name_quoted))
-    dbExecute(conn, paste0("RELEASE SAVEPOINT ", name_quoted))
-  }
-
-  invisible(TRUE)
-})
-
 compat_name <- function(name, .name) {
   if (!is.null(.name)) {
     warning("Please use `dbBegin(..., name = \"<savepoint>\")` to specify the name of the savepoint.",
@@ -114,3 +70,9 @@ get_savepoint_id <- function(name) {
   random_string <- paste(sample(letters, 10, replace = TRUE), collapse = "")
   paste0(name, "_", Sys.getpid(), "_", random_string)
 }
+
+#' @export
+#' @name sqlite-transaction
+sqliteIsTransacting <- function(conn) {
+  return(connection_in_transaction(conn@ptr))
+}
