@@ -3,7 +3,7 @@
 
 #include <boost/noncopyable.hpp>
 #include <boost/shared_ptr.hpp>
-#include "sqlite3.h"
+#include "sqlite3-cpp.h"
 
 class DbResult;
 
@@ -19,8 +19,13 @@ typedef boost::shared_ptr<DbConnection> DbConnectionPtr;
 class DbConnection : boost::noncopyable {
 public:
   // Create a new connection handle
-  DbConnection(const std::string& path, bool allow_ext,
-               int flags, const std::string& vfs = "", bool with_alt_types = false);
+  DbConnection(
+    const std::string& path,
+    bool allow_ext,
+    int flags,
+    const std::string& vfs = "",
+    bool with_alt_types = false
+  );
   ~DbConnection();
 
 public:
@@ -51,12 +56,14 @@ public:
 
   void set_busy_handler(SEXP r_callback);
 
+  bool in_transaction() const;
+
 private:
   sqlite3* pConn_;
   const bool with_alt_types_;
   SEXP busy_callback_;
   void release_callback_data();
-  static int busy_callback_helper(void *data, int num);
+  static int busy_callback_helper(void* data, int num);
 };
 
-#endif // __RSQLITE_SQLITE_CONNECTION__
+#endif  // __RSQLITE_SQLITE_CONNECTION__
