@@ -7,7 +7,7 @@
 class SqliteColumnDataSource : public DbColumnDataSource {
   sqlite3_stmt* stmt;
   const bool with_alt_types;
-  
+
 public:
   SqliteColumnDataSource(sqlite3_stmt* stmt, const int j, bool with_alt_types);
 
@@ -29,7 +29,10 @@ public:
   virtual double fetch_time() const;
 
 private:
-  static DATA_TYPE datatype_from_decltype(const char* decl_type, bool with_alt_types);
+  static DATA_TYPE datatype_from_decltype(
+    const char* decl_type,
+    bool with_alt_types
+  );
 
 private:
   sqlite3_stmt* get_stmt() const;
@@ -39,4 +42,4 @@ private:
   static bool needs_64_bit(const int64_t ret);
 };
 
-#endif // RSQLITE_SQLITECOLUMNDATASOURCE_H
+#endif  // RSQLITE_SQLITECOLUMNDATASOURCE_H
