@@ -7,10 +7,10 @@ astyle <- function(extra_args = character()) {
   astyle_args <- c(
     "-n",
     "--indent=spaces=2",
-    "--indent-namespaces",
-    "--indent-preproc-block",
+    "--indent-cases",
     "--unpad-paren",
     "--pad-header",
+    "--pad-oper",
     "--min-conditional-indent=0",
     "--align-pointer=type",
     "--align-reference=type"
@@ -29,7 +29,7 @@ astyle <- function(extra_args = character()) {
     }
   )
   src_files <- dir(src_path, "[.](?:cpp|h)$", recursive = FALSE, full.names = TRUE)
-  astyle_files <- grep("(?:RcppExports[.]cpp)", src_files, value = TRUE, invert = TRUE)
+  astyle_files <- grep("(?:cpp11[.]cpp)", src_files, value = TRUE, invert = TRUE)
   output <- system2(astyle_cmd, c(astyle_args, astyle_files, extra_args), stdout = TRUE, stderr = TRUE)
   unchanged <- grepl("^Unchanged", output)
   if (any(!unchanged)) {
